@@ -1,10 +1,9 @@
 import argparse,sys,os
 import yac.cli.stack
-import yac.cli.vpc
-import yac.cli.app
+import yac.cli.service
 import yac.cli.db
-import yac.cli.naming
-import yac.cli.security
+import yac.cli.prefs
+import yac.cli.container
 
 from yac.cli.primer import show_primer
 
@@ -31,25 +30,17 @@ def main():
 
             return yac.cli.stack.main()
 
-        if command == 'app':
+        elif command == 'service':
 
-            return yac.cli.app.main()
+            return yac.cli.service.main()
 
-        elif command == 'vpc':
+        elif command == 'prefs':
 
-            return yac.cli.vpc.main()
+            return yac.cli.prefs.main()    
 
-        elif command == 'db':
+        elif command == 'container':
 
-            return yac.cli.db.main()
-
-        elif command == 'naming':
-
-            return yac.cli.naming.main()
-
-        elif command == 'security':
-
-            return yac.cli.security.main()            
+            return yac.cli.container.main()    
 
         else:
 
