@@ -1,8 +1,8 @@
 import argparse,sys,os
-from yac.lib.config import get_root_path
+from yac.lib.paths import get_root_path
 from sets import Set
 
-yac_commands = ['stack', 'app', 'db', 'vpc', 'naming', 'security', 'primer', 'setup', 'restore']
+yac_commands = ['stack', 'service', 'prefs', 'primer', 'container']
 
 def show_primer(command_array):
 
