@@ -33,4 +33,19 @@ def get_latest_version(app, container_org, registry_url='https://registry.hub.do
                 versions.sort()
                 latest_version = versions[-1]
 
-    return str(latest_version)
\ No newline at end of file
+    return str(latest_version)
+
+def get_app_version(app_alias, my_service_descriptor):
+
+    app_version = ""
+
+    # the version would be in the image for this app
+    search_str = "task-definition.containerDefinitions[?name=='%s'].image"%app_alias
+    images_found = jmespath.search(search_str, my_service_descriptor)
+
+    if images_found and len(images_found)==1:
+
+        # grab the version from the tail end of the image label
+        app_version = str(images_found[0]).split(':')[-1]
+
+    return app_version    
\ No newline at end of file
